# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from chat_server_connector_v2.api.chats_v2_api import ChatsV2Api


class TestChatsV2Api(unittest.IsolatedAsyncioTestCase):
    """ChatsV2Api unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = ChatsV2Api()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_chat_api_chat_ai_usage_insert_v2(self) -> None:
        """Test case for chat_api_chat_ai_usage_insert_v2

        Chat Ai Usage Insert V2
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from chat_server_connector_v2.models.chat_type import ChatType
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class ChatNew(BaseModel):
    """
    ChatNew
    """ # noqa: E501
    chat_type: ChatType
    avatar_id: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    description: Optional[StrictStr] = None
    messaging_enabled: Optional[StrictBool] = True
    permalink_enabled: Optional[StrictBool] = False
    is_visible: Optional[StrictBool] = True
    topic_slug: Optional[StrictStr] = None
    add_members: Optional[List[StrictInt]] = None
    __properties: ClassVar[List[str]] = ["chat_type", "avatar_id", "name", "description", "messaging_enabled", "permalink_enabled", "is_visible", "topic_slug", "add_members"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ChatNew from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ChatNew from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "chat_type": obj.get("chat_type"),
            "avatar_id": obj.get("avatar_id"),
            "name": obj.get("name"),
            "description": obj.get("description"),
            "messaging_enabled": obj.get("messaging_enabled") if obj.get("messaging_enabled") is not None else True,
            "permalink_enabled": obj.get("permalink_enabled") if obj.get("permalink_enabled") is not None else False,
            "is_visible": obj.get("is_visible") if obj.get("is_visible") is not None else True,
            "topic_slug": obj.get("topic_slug"),
            "add_members": obj.get("add_members")
        })
        return _obj


